#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class GannHiLoActivator : Indicator
    {
        #region Variables
      	private int r = 10;
		private double swing;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Teal), PlotStyle.Line, "HiLo"));
            CalculateOnBarClose	= false;
            Overlay				= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
         	double val1_high	= SMA(High, r)[0];
			double val2_low		= SMA(Low, r)[0];
			
			if (Close[0] < val2_low)	swing = -1;
			if (Close[0] > val1_high)	swing = 1;
			
			if (swing == 1)
			{
				HiLo.Set(val2_low);
			}
			else if (swing == -1)
			{
				HiLo.Set(val1_high);
			}
			
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries HiLo
        {
            get { return Values[0]; }
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private GannHiLoActivator[] cacheGannHiLoActivator = null;

        private static GannHiLoActivator checkGannHiLoActivator = new GannHiLoActivator();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public GannHiLoActivator GannHiLoActivator()
        {
            return GannHiLoActivator(Input);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public GannHiLoActivator GannHiLoActivator(Data.IDataSeries input)
        {

            if (cacheGannHiLoActivator != null)
                for (int idx = 0; idx < cacheGannHiLoActivator.Length; idx++)
                    if (cacheGannHiLoActivator[idx].EqualsInput(input))
                        return cacheGannHiLoActivator[idx];

            GannHiLoActivator indicator = new GannHiLoActivator();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.SetUp();

            GannHiLoActivator[] tmp = new GannHiLoActivator[cacheGannHiLoActivator == null ? 1 : cacheGannHiLoActivator.Length + 1];
            if (cacheGannHiLoActivator != null)
                cacheGannHiLoActivator.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheGannHiLoActivator = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.GannHiLoActivator GannHiLoActivator()
        {
            return _indicator.GannHiLoActivator(Input);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.GannHiLoActivator GannHiLoActivator(Data.IDataSeries input)
        {
            return _indicator.GannHiLoActivator(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.GannHiLoActivator GannHiLoActivator()
        {
            return _indicator.GannHiLoActivator(Input);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.GannHiLoActivator GannHiLoActivator(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.GannHiLoActivator(input);
        }

    }
}
#endregion
